From 8d2b90c34baa60e7fa6ac8d2800ef69d104bf462 Mon Sep 17 00:00:00 2001
From: Hadrien Grasland <grasland@lal.in2p3.fr>
Date: Tue, 25 Feb 2020 10:49:08 +0100
Subject: [PATCH] Update histops tutorial to new RHist addition semantics

---
 tutorials/v7/histops.cxx | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/tutorials/v7/histops.cxx b/tutorials/v7/histops.cxx
index 10c2dfd29b3..6451bbb4e8e 100644
--- a/tutorials/v7/histops.cxx
+++ b/tutorials/v7/histops.cxx
@@ -25,14 +25,14 @@ void histops()
    using namespace ROOT::Experimental;
    // Create a 2D histogram with an X axis with equidistant bins, and a y axis
    // with irregular binning.
-   RH2D hist1({100, 0., 1.}, {{0., 1., 2., 3., 10.}});
+   RH2D hist1({10, 0., 1.}, {{0., 1., 2., 3., 10.}});
 
    // Fill weight 1. at the coordinate 0.01, 1.02.
    hist1.Fill({0.01, 1.02});
 
    RH2D hist2({{{10, 0., 1.}, {{0., 1., 2., 3., 10.}}}});
-   // Fill weight 1. at the coordinate 0.01, 1.02.
-   hist2.Fill({0.01, 1.02});
+   // Fill weight 1. at the coordinate 0.02, 1.03 (that's the same bin).
+   hist2.Fill({0.02, 1.03});
 
    Add(hist1, hist2);
 
-- 
GitLab